Fonts
~~~~~
``font_manager.JSONEncoder`` has been removed. Use `.font_manager.json_dump` to
dump a `.FontManager` instance.

``font_manager.createFontList`` has been removed. `.font_manager.FontManager.addfont`
is now available to register a font at a given path.

The ``as_str``, ``as_rgba_str``, ``as_array``, ``get_width`` and ``get_height``
methods of ``matplotlib.ft2font.FT2Image`` have been removed. Convert the
``FT2Image`` to a NumPy array with ``np.asarray`` before processing it.
